about summary refs log tree commit diff
path: root/strlcpy.c
diff options
context:
space:
mode:
authorChristian Neukirchen <chneukirchen@gmail.com>2015-01-24 19:04:46 +0100
committerChristian Neukirchen <chneukirchen@gmail.com>2015-01-24 19:04:46 +0100
commit976d77c76d72e19aa50929b56bb94ae914eee968 (patch)
treef4021d3a66443851a12a0c9da477fee66ca76d28 /strlcpy.c
parentb7a8c11750d11721a897fdb8442d52f15e7a24a0 (diff)
downloadcwm-976d77c76d72e19aa50929b56bb94ae914eee968.tar.gz
cwm-976d77c76d72e19aa50929b56bb94ae914eee968.tar.xz
cwm-976d77c76d72e19aa50929b56bb94ae914eee968.zip
update imported str*.c
Diffstat (limited to 'strlcpy.c')
-rw-r--r--strlcpy.c41
1 files changed, 20 insertions, 21 deletions
diff --git a/strlcpy.c b/strlcpy.c
index 30a260c..75d7d4a 100644
--- a/strlcpy.c
+++ b/strlcpy.c
@@ -1,7 +1,7 @@
-/*	$OpenBSD: strlcpy.c,v 1.10 2005/08/08 08:05:37 espie Exp $	*/
+/*	$OpenBSD: strlcpy.c,v 1.12 2015/01/15 03:54:12 millert Exp $	*/
 
 /*
- * Copyright (c) 1998 Todd C. Miller <Todd.Miller@courtesan.com>
+ * Copyright (c) 1998, 2015 Todd C. Miller <Todd.Miller@courtesan.com>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -25,34 +25,33 @@
 #ifndef HAVE_STRLCPY
 
 /*
  * Copy src to string dst of size siz.  At most siz-1 characters
  * will be copied.  Always NUL terminates (unless siz == 0).
  * Returns strlen(src); if retval >= siz, truncation occurred.
  */
 size_t
-strlcpy(char *dst, const char *src, size_t siz)
+strlcpy(char *dst, const char *src, size_t dsize)
 {
-	char *d = dst;
-	const char *s = src;
-	size_t n = siz;
-
-	/* Copy as many bytes as will fit */
-	if (n != 0 && --n != 0) {
-		do {
-			if ((*d++ = *s++) == 0)
+	const char *osrc = src;
+	size_t nleft = dsize;
+
+	/* Copy as many bytes as will fit. */
+	if (nleft != 0) {
+		while (--nleft != 0) {
+			if ((*dst++ = *src++) == '\0')
 				break;
-		} while (--n != 0);
+		}
 	}
 
-	/* Not enough room in dst, add NUL and traverse rest of src */
-	if (n == 0) {
-		if (siz != 0)
-			*d = '\0';		/* NUL-terminate dst */
-		while (*s++)
+	/* Not enough room in dst, add NUL and traverse rest of src. */
+	if (nleft == 0) {
+		if (dsize != 0)
+			*dst = '\0';		/* NUL-terminate dst */
+		while (*src++)
 			;
 	}
 
-	return(s - src - 1);	/* count does not include NUL */
+	return(src - osrc - 1);	/* count does not include NUL */
 }
 
 #endif /* !HAVE_STRLCPY */
@@ -25,34 +25,33 @@
 
 /*
- * Copy src to string dst of size siz.  At most siz-1 characters
- * will be copied.  Always NUL terminates (unless siz == 0).
- * Returns strlen(src); if retval >= siz, truncation occurred.
+ * Copy string src to buffer dst of size dsize.  At most dsize-1
+ * chars will be copied.  Always NUL terminates (unless dsize == 0).
+ * Returns strlen(src); if retval >= dsize, truncation occurred.
  */
 size_t